@@ -13,7 +13,7 @@ setMethod("rectLookup", "QuadTree",
               xlims = sort(c(ptOne[1], ptTwo[1]))
             if(missing(ylims))
               ylims = sort(c(ptOne[2], ptTwo[2]))
-            .Call("R_Rectangle_Lookup", tree, as.numeric(xlims), as.numeric(ylims))
+            .Call(C_Rectangle_Lookup, tree, as.numeric(xlims), as.numeric(ylims))
           }
           )
 
@@ -25,11 +25,11 @@ findMaxDepth = function(maxDepth, minNodeArea, xlim, ylim)
       {
         totArea = (xlim[2] - xlim[1]) * (ylim[2] - ylim[1])
         areas = which(totArea / (4^(1:10)) <= minNodeArea)
-        
+
         if(!length(areas))
           {
             warning("The minNodeArea selected lead to a maximum depth > 10, which is very memory intensive for negligable benefit. Using maximum depth of 10.")
-           
+
             maxDepth = 10
           } else {
             maxDepth = areas[1]
@@ -38,7 +38,7 @@ findMaxDepth = function(maxDepth, minNodeArea, xlim, ylim)
       }
     as.integer(maxDepth)
   }
-    
+
 
 createTree = function(data, treeType = "quad", dataType = "point", columns = if (dataType=="point") 1:2 else 1:4, ...)
   {
@@ -48,7 +48,7 @@ createTree = function(data, treeType = "quad", dataType = "point", columns = if
           {
             if(length(columns) != 2)
               stop("wrong number of columns for this index type.")
-            x = data[,columns[1]] 
+            x = data[,columns[1]]
             y = data[,columns[2]]
             ret = quadTree2(x,y, ... )
           } else if (dataType == "rect") {
@@ -60,19 +60,19 @@ createTree = function(data, treeType = "quad", dataType = "point", columns = if
         ret
       }
   }
-        
+
 quadTree2 = function(x, y, maxDepth = 7, minNodeArea, ...)
-  { 
+  {
     xrange = range(x)
     yrange = range(y)
     maxDepth = findMaxDepth(maxDepth, minNodeArea, xrange, yrange)
 
     x = as.numeric(x)
     y = as.numeric(y)
-    .Call("R_Build_Quadtree_Pt", x, y, max(x), min(x), max(y), min(y), maxDepth)
+    .Call(C_Build_Quadtree_Pt, x, y, max(x), min(x), max(y), min(y), maxDepth)
 
   }
-  
+
 rectTree = function(x1, x2, y1, y2, maxDepth = 7, minNodeArea, ...)
   {
     x1 = as.numeric(x1)
@@ -82,7 +82,7 @@ rectTree = function(x1, x2, y1, y2, maxDepth = 7, minNodeArea, ...)
     xlim = c(min(x1), max(x2))
     ylim = c(min(y1), max(y2))
     maxDepth = findMaxDepth(maxDepth, minNodeArea, xlim, ylim)
-    .Call("R_Build_Quadtree_Rect", x1, x2, y1, y2, max(x2), min(x1), max(y2), min(y1), maxDepth)
+    .Call(C_Build_Quadtree_Rect, x1, x2, y1, y2, max(x2), min(x1), max(y2), min(y1), maxDepth)
   }
 setGeneric("knnLookup",
            function(tree, newx, newy, newdat, columns=1:2,   k = 5)
@@ -97,7 +97,7 @@ setMethod("knnLookup", "QuadTree",
               newx = as.numeric(newdat[,columns[1]])
             if(missing(newy))
               newy = as.numeric(newdat[,columns[2]])
-            inds = .Call("R_Find_Neighbors_Pts", tree, newx, newy, k )
+            inds = .Call(C_Find_Neighbors_Pts, tree, newx, newy, k )
             matrix(inds, byrow = TRUE, ncol = k)
           }
           )
